<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtWorldClock</name>
    <message>
        <location filename="../lxqtworldclock.cpp" line="246"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;yyyy/M/d (ddd)&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfiguration</name>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="14"/>
        <source>World Clock Settings</source>
        <translation>世界時計の設定</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="24"/>
        <source>Display &amp;format</source>
        <translation>表示形式(&amp;F)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="30"/>
        <source>&amp;Time</source>
        <translation>時刻(&amp;T)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="39"/>
        <source>F&amp;ormat:</source>
        <translation>形式(&amp;O):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="50"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="176"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="272"/>
        <source>Short</source>
        <translation>短い</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="55"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="181"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="277"/>
        <source>Long</source>
        <translation>長い</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="60"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="287"/>
        <source>Custom</source>
        <translation>指定する</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="89"/>
        <source>Sho&amp;w seconds</source>
        <translation>秒を表示する(&amp;W)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="96"/>
        <source>Pad &amp;hour with zero</source>
        <translation>時が一桁のとき 0 で埋める(&amp;H)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="103"/>
        <source>&amp;Use 12-hour format</source>
        <translation>12 時間制で表示する(&amp;U)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="116"/>
        <source>T&amp;ime zone</source>
        <translation>タイムゾーン(&amp;I)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="128"/>
        <source>&amp;Position:</source>
        <translation>位置(&amp;P):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="138"/>
        <source>For&amp;mat:</source>
        <translation>形式(&amp;M):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="149"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="238"/>
        <source>Below</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="154"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="243"/>
        <source>Above</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="159"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="248"/>
        <source>Before</source>
        <translation>前</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="164"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="253"/>
        <source>After</source>
        <translation>後</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="186"/>
        <source>Offset from UTC</source>
        <translation>UTC からの時差</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="191"/>
        <source>Abbreviation</source>
        <translation>短縮形</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="196"/>
        <source>Location identifier</source>
        <translation>場所</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="431"/>
        <source>IANA id</source>
        <translation>IANA の ID</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
        <source>Show &amp;week numbers in popup calendar</source>
        <translation>ポップアップするカレンダーに週番号を表示する(&amp;W)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
        <source>S&amp;how tooltip</source>
        <translation>ツールチップを表示する(&amp;H)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
        <location filename="../lxqtworldclockconfiguration.cpp" line="586"/>
        <source>Custom name</source>
        <translation>指定した名前</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="212"/>
        <source>&amp;Date</source>
        <translation>日付(&amp;D)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="227"/>
        <source>Po&amp;sition:</source>
        <translation>位置(&amp;S):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="261"/>
        <source>Fo&amp;rmat:</source>
        <translation>形式(&amp;R):</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="282"/>
        <source>ISO 8601</source>
        <translation>ISO 8601</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="316"/>
        <source>Show &amp;year</source>
        <translation>年を表示する(&amp;Y)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="323"/>
        <source>Show day of wee&amp;k</source>
        <translation>曜日を表示する(&amp;K)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="330"/>
        <source>Pad d&amp;ay with zero</source>
        <translation>日が一桁のとき 0 で埋める(&amp;A)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="337"/>
        <source>&amp;Long month and day of week names</source>
        <translation>月や曜日を長い名前で表示する(&amp;L)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="350"/>
        <source>Ad&amp;vanced manual format</source>
        <translation>形式を詳しく指定する(&amp;V)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="377"/>
        <source>&amp;Customise ...</source>
        <translation>指定する(&amp;C) ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="403"/>
        <source>Time &amp;zones</source>
        <translation>タイムゾーン(&amp;Z)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="446"/>
        <source>&amp;Add ...</source>
        <translation>追加(&amp;A) ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="456"/>
        <source>&amp;Remove</source>
        <translation>削除(&amp;R)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="466"/>
        <source>Set as &amp;default</source>
        <translation>デフォルトにする(&amp;D)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="476"/>
        <source>&amp;Edit custom name ...</source>
        <translation>名前を付ける(&amp;E) ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="486"/>
        <source>Move &amp;up</source>
        <translation>上へ(&amp;U)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="496"/>
        <source>Move do&amp;wn</source>
        <translation>下へ(&amp;W)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="519"/>
        <source>&amp;General</source>
        <translation>一般(&amp;G)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="525"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>パネルが垂直なときには回転する(&amp;R)</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="107"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;yyyy/M/d (ddd)&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="585"/>
        <source>Input custom time zone name</source>
        <translation>タイムゾーンの名前を入力</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationManualFormat</name>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="14"/>
        <source>World Clock Manual Format Configuration</source>
        <translation>世界時計の形式の手動設定</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="83"/>
        <source>&lt;h1&gt;Custom Date/Time Format Syntax&lt;/h1&gt;
&lt;p&gt;A date pattern is a string of characters, where specific strings of characters are replaced with date and time data from a calendar when formatting or used to generate data for a calendar when parsing.&lt;/p&gt;
&lt;p&gt;The Date Field Symbol Table below contains the characters used in patterns to show the appropriate formats for a given locale, such as yyyy for the year. Characters may be used multiple times. For example, if y is used for the year, &apos;yy&apos; might produce &apos;99&apos;, whereas &apos;yyyy&apos; produces &apos;1999&apos;. For most numerical fields, the number of characters specifies the field width. For example, if h is the hour, &apos;h&apos; might produce &apos;5&apos;, but &apos;hh&apos; produces &apos;05&apos;. For some characters, the count specifies whether an abbreviated or full form should be used, but may have other choices, as given below.&lt;/p&gt;
&lt;p&gt;Two single quotes represents a literal single quote, either inside or outside single quotes. Text within single quotes is not interpreted in any way (except for two adjacent single quotes). Otherwise all ASCII letter from a to z and A to Z are reserved as syntax characters, and require quoting if they are to represent literal characters. In addition, certain ASCII punctuation characters may become variable in the future (eg &quot;:&quot; being interpreted as the time separator and &apos;/&apos; as a date separator, and replaced by respective locale-sensitive characters in display).&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Code&lt;/th&gt;&lt;th&gt;Meaning&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;the day as number without a leading zero (1 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;the day as number with a leading zero (01 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;the month as number without a leading zero (1-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;the month as number with a leading zero (01-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;the year as two digit number (00-99)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;the year as four digit number&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23 or 1 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23 or 01 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;the minute without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;the offset from UTC&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;the timezone IANA id&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;the timezone abbreviation&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;the timezone short display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;the timezone long display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
</source>
        <translation>&lt;h1&gt;カスタム用の日付時刻フォーマットの形式&lt;/h1&gt;
&lt;p&gt;日付パターンは文字列です。解析時にはカレンダー時計からデータを生成・フォーマットされ、特定の文字列がカレンダー時計の日付と時刻のデータに置き換わります。&lt;/p&gt;
&lt;p&gt;
以下の日付フィールドの記号表には、年の yyyy など、特定の場所に適した形式を表すためのパターンの文字列があります。
 文字は複数回使用できます。例えば、y が年に使用されている場合、 yy は 99 を生成しますが、 yyyy は 1999 を生成します。
ほとんどの数値フィールドでは、文字数がフィールド幅を指定します。
 例えば、時刻の h の場合、 h は 5 を生成しますが、 hh は 05 を生成します。
一部の文字では、この文字の並びの数は省略形か完全形のどちらを使用するかを指定しますが、以下の表に示すように他の使用方法もあります。
&lt;/p&gt;&lt;p&gt;
2つの連続した一重引用符は、文字内か外側の１つの一重引用符を表します。
一重引用符内のテキストは、変換されません（隣接する２つの引用符を除く）。
それ以外の場合、 a から z および A から Z までのすべてのASCII文字は形式の文字として予約されており、文字自身を表す場合は引用符が必要です。
さらに、特定のASCII記号は将来変更になる可能性があります（例: &quot;:&quot; は時刻の区切り文字として、 &apos;/&apos; は日付の区切り文字としてみられ、それぞれのロケール依存文字に置き換えられます）。
&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;記号&lt;/th&gt;&lt;th&gt;意味&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; d&lt;/td&gt; &lt;td&gt;日（1〜31）先頭に0を付けない数字&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt; &lt;td&gt;日（01〜31）先頭に0を付けた数字&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt; &lt;td&gt;ローカライズされた曜日の短縮名（例: &apos;月&apos;から &apos;日&apos;）。&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt; &lt;td&gt;ローカライズされた長い曜日名（例: &apos;月曜日&apos;から &apos;日曜日&apos;）。&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; M &lt;/ td&gt; &lt;td&gt;月（1〜12）先頭に0を付けない数字&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; MM &lt;/ td&gt; &lt;td&gt;月（01-12）先頭に0を付けた数字&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; MMM&lt;/td&gt; &lt;td&gt;ローカライズされた月の省略名（例: &apos;1月&apos;から &apos;12月&apos;）。&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; MMMM&lt;/td&gt; &lt;td&gt;ローカライズされた長い月の名前（例: &apos;1月&apos;から &apos;12月&apos;）。(訳注: 日本語では MMM と MMMM は同じ表示のようです)&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt; &lt;td&gt;年（00〜99）2桁の数字&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; yyyy&lt;/td&gt; &lt;td&gt;年を4桁の数字&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt; &lt;td&gt;時刻（0〜23、または午前/午後を表示する場合は1〜12）先頭に0なし&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt; &lt;td&gt;時刻（00から23、または午前/午後を表示する場合は01から12）先頭に0がつく&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt; &lt;td&gt;時刻（午前/午後の表示でも0〜23）先頭に0なし&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt; &lt;td&gt;時刻（午前/午後の表示でも00〜23）先頭に0がつく&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; m&lt;/td&gt; &lt;td&gt;分（0〜59）先頭に0なし&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; mm&lt;/td&gt; &lt;td&gt;分（00から59）先頭に0がつく&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; s&lt;/td&gt; &lt;td&gt;秒（0〜59）先頭に0なし&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt; &lt;td&gt;秒（00〜59）先頭に0がつく&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; AP &lt;i&gt;または&lt;/i&gt; A &lt;/td&gt; &lt;td&gt;午前/午後の表示に使用します。 &lt;b&gt; A/AP &lt;/b&gt;は &quot;AM&quot; または &quot;PM&quot; に置き換えられます。&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt; &lt;td&gt; ap &lt;i&gt;または&lt;/i&gt; a &lt;/td&gt; &lt;td&gt;午前/午後の表示に使用します。 &lt;b&gt; a/ap &lt;/b&gt;は &quot;am&quot; または &quot;pm&quot; に置き換えられます。（訳注: 日本語では AP と ap はどちらも&quot;午前&quot;または&quot;午後&quot;に置き換えられるようです）&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt; &lt;td&gt;タイムゾーン（例: &quot;JST&quot;）&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt; T&lt;/td&gt; &lt;td&gt; UTC(世界協定時)からの時差&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt; &lt;td&gt;タイムゾーンの IANA ID &lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt; &lt;td&gt;タイムゾーンの省略形&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt; &lt;td&gt;タイムゾーンの短い表示名&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt; &lt;td&gt;タイムゾーンの長い表示名&lt;/td&gt; &lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt; &lt;td&gt;タイムゾーンのカスタム名。設定ウィンドウの[タイムゾーン]タブで変更できます。&lt;/td&gt; &lt;/tr&gt; &lt;/table&gt;
&lt;br /&gt;&lt;b&gt;注意:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;
パターン内の [&apos;a&apos; .. &apos;z&apos;] と [&apos;A&apos; .. &apos;Z&apos;] の範囲内にない文字は引用テキストとして扱われます。
たとえば、 &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos;, &apos;@&apos;などの文字は、一重引用符(&apos;)で囲まれていなくても、結果のテキストに表示されます。
一重引用符(&apos;)は、文字を“エスケープ”するために使用されます。行内の2つの連続した一重引用符は、引用符付き文字列の内側でも外側でも、“実際”の1つの一重引用符を表します。
&lt;/li&gt;&lt;li&gt;
最小の更新間隔は1秒です。
z または zzz が設定されている場合、時刻はミリ秒単位で表示されますが、ミリ秒単位では更新されません（大きなパフォーマンスの低下を避けるため）。
&lt;/li&gt;&lt;ul&gt;
</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationTimeZones</name>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="14"/>
        <source>World Clock Time Zones</source>
        <translation>世界時計のタイムゾーン</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="36"/>
        <source>Time zone</source>
        <translation>都市</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="41"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="46"/>
        <source>Comment</source>
        <translation>備考</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="51"/>
        <source>Country</source>
        <translation>国名</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="117"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="120"/>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="128"/>
        <source>Other</source>
        <translation>その他</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="129"/>
        <source>Local timezone</source>
        <translation>ローカルなタイムゾーン</translation>
    </message>
</context>
</TS>
